@@ -2,23 +2,22 @@ from typing import Union, TextIO, Iterator, List, Mapping
 
 import yaml
 
-from .generic_resource import GenericGlobalResource, GenericNamespacedResource, create_resources_from_crd
+from .generic_resource import (
+    GenericGlobalResource,
+    GenericNamespacedResource,
+    create_resources_from_crd,
+)
 from .core.exceptions import LoadResourceError
 from .core.resource_registry import resource_registry
 
-__all__ = [
-    'from_dict',
-    'load_all_yaml',
-    'dump_all_yaml',
-    'resource_registry'
-]
+__all__ = ["from_dict", "load_all_yaml", "dump_all_yaml", "resource_registry"]
 
 try:
     import jinja2
 except ImportError:
     jinja2 = None
 
-REQUIRED_ATTR = ('apiVersion', 'kind')
+REQUIRED_ATTR = ("apiVersion", "kind")
 
 AnyResource = Union[GenericGlobalResource, GenericNamespacedResource]
 
@@ -35,16 +34,23 @@ def from_dict(d: dict) -> AnyResource:
       always required.
     """
     if not isinstance(d, Mapping):
-        raise LoadResourceError(f"Invalid resource definition, not a dict.")
+        raise LoadResourceError("Invalid resource definition, not a dict.")
     for attr in REQUIRED_ATTR:
         if attr not in d:
-            raise LoadResourceError(f"Invalid resource definition, key '{attr}' missing.")
+            raise LoadResourceError(
+                f"Invalid resource definition, key '{attr}' missing."
+            )
 
-    model = resource_registry.load(d['apiVersion'], d['kind'])
+    model = resource_registry.load(d["apiVersion"], d["kind"])
     return model.from_dict(d)
 
 
-def load_all_yaml(stream: Union[str, TextIO], context: dict = None, template_env = None, create_resources_for_crds: bool = False) -> List[AnyResource]:
+def load_all_yaml(
+    stream: Union[str, TextIO],
+    context: dict = None,
+    template_env=None,
+    create_resources_for_crds: bool = False,
+) -> List[AnyResource]:
     """Load kubernetes resource objects defined as YAML. See `from_dict` regarding how resource types are detected.
     Returns a list of resource objects or raise a `LoadResourceError`.  Skips any empty YAML documents in the
     stream, returning an empty list if all YAML documents are empty. Deep parse any items from .*List resources.
@@ -80,7 +86,10 @@ def load_all_yaml(stream: Union[str, TextIO], context: dict = None, template_env
                 res = from_dict(obj)
                 resources.append(res)
 
-                if create_resources_for_crds is True and res.kind == "CustomResourceDefinition":
+                if (
+                    create_resources_for_crds is True
+                    and res.kind == "CustomResourceDefinition"
+                ):
                     create_resources_from_crd(res)
         return resources
 
@@ -101,7 +110,9 @@ def dump_all_yaml(resources: List[AnyResource], stream: TextIO = None, indent=2)
     return yaml.safe_dump_all(res, stream, indent=indent)
 
 
-def _template(stream: Union[str, TextIO], context: dict = None, template_env = None) -> List[AnyResource]:
+def _template(
+    stream: Union[str, TextIO], context: dict = None, template_env=None
+) -> List[AnyResource]:
     """
     Template a stream using jinja2 and the given context
     """
@@ -113,5 +124,7 @@ def _template(stream: Union[str, TextIO], context: dict = None, template_env = N
     elif not isinstance(template_env, jinja2.Environment):
         raise LoadResourceError("template_env is not a valid jinja2 template")
 
-    tmpl = template_env.from_string(stream if isinstance(stream, str) else stream.read())
+    tmpl = template_env.from_string(
+        stream if isinstance(stream, str) else stream.read()
+    )
     return tmpl.render(**context)
