@@ -11,12 +11,26 @@ from .models import Cluster, User, UserExec, FileStr
 from ..core.exceptions import ConfigError
 
 
-def Client(config: SingleConfig, timeout: httpx.Timeout, trust_env: bool = True) -> httpx.Client:
-    return httpx.Client(**httpx_parameters(config, timeout, trust_env))
+def Client(
+    config: SingleConfig,
+    timeout: httpx.Timeout,
+    trust_env: bool = True,
+    transport: httpx.BaseTransport = None,
+) -> httpx.Client:
+    return httpx.Client(
+        transport=transport, **httpx_parameters(config, timeout, trust_env)
+    )
 
 
-def AsyncClient(config: SingleConfig, timeout: httpx.Timeout, trust_env: bool = True) -> httpx.AsyncClient:
-    return httpx.AsyncClient(**httpx_parameters(config, timeout, trust_env))
+def AsyncClient(
+    config: SingleConfig,
+    timeout: httpx.Timeout,
+    trust_env: bool = True,
+    transport: httpx.AsyncBaseTransport = None,
+) -> httpx.AsyncClient:
+    return httpx.AsyncClient(
+        transport=transport, **httpx_parameters(config, timeout, trust_env)
+    )
 
 
 def httpx_parameters(config: SingleConfig, timeout: httpx.Timeout, trust_env: bool):
@@ -41,18 +55,26 @@ class BearerAuth(httpx.Auth):
 
 async def async_check_output(command, env):
     PIPE = asyncio.subprocess.PIPE
-    proc = await asyncio.create_subprocess_exec(*command, env=env, stdin=None, stdout=PIPE, stderr=PIPE)
+    proc = await asyncio.create_subprocess_exec(
+        *command, env=env, stdin=None, stdout=PIPE, stderr=PIPE
+    )
     stdout, stderr = await proc.communicate()
     if proc.returncode != 0:
-        raise ConfigError(f"Exec {command[0]} returned {proc.returncode}: {stderr.decode()}")
+        raise ConfigError(
+            f"Exec {command[0]} returned {proc.returncode}: {stderr.decode()}"
+        )
     return stdout
 
 
 def sync_check_output(command, env):
-    proc = subprocess.Popen(command, env=env, stdin=None, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    proc = subprocess.Popen(
+        command, env=env, stdin=None, stdout=subprocess.PIPE, stderr=subprocess.PIPE
+    )
     stdout, stderr = proc.communicate()
     if proc.returncode != 0:
-        raise ConfigError(f"Exec {command[0]} returned {proc.returncode}: {stderr.decode()}")
+        raise ConfigError(
+            f"Exec {command[0]} returned {proc.returncode}: {stderr.decode()}"
+        )
     return stdout
 
 
@@ -63,10 +85,16 @@ class ExecAuth(httpx.Auth):
 
     def _prepare(self):
         exec = self._exec
-        if exec.apiVersion not in ("client.authentication.k8s.io/v1alpha1", "client.authentication.k8s.io/v1beta1"):
-            raise ConfigError(f"auth exec api version {exec.apiVersion} not implemented")
+        if exec.apiVersion not in (
+            "client.authentication.k8s.io/v1alpha1",
+            "client.authentication.k8s.io/v1beta1",
+        ):
+            raise ConfigError(
+                f"auth exec api version {exec.apiVersion} not implemented"
+            )
         cmd_env_vars = dict(os.environ)
-        cmd_env_vars.update((var.name, var.value) for var in exec.env)
+        if exec.env:
+            cmd_env_vars.update((var.name, var.value) for var in exec.env)
         # TODO: add support for passing KUBERNETES_EXEC_INFO env var
         # https://github.com/kubernetes/community/blob/master/contributors/design-proposals/auth/kubectl-exec-plugins.md
         args = exec.args if exec.args else []
@@ -121,7 +149,7 @@ def user_cert(user: User, abs_file):
     if user.client_cert or user.client_cert_data:
         return (
             FileStr(user.client_cert_data) or abs_file(user.client_cert),
-            FileStr(user.client_key_data) or abs_file(user.client_key)
+            FileStr(user.client_key_data) or abs_file(user.client_key),
         )
     return None
 
