@@ -8,18 +8,18 @@ try:
     except:
         from ..resources import apiextensions_v1beta1 as apiextensions
 except:
-    if sys.modules["__main__"].__package__ != 'mkdocs':   # we ignore this import error during documentation generation
+    if (
+        sys.modules["__main__"].__package__ != "mkdocs"
+    ):  # we ignore this import error during documentation generation
         raise
     from unittest import mock
 
-
     class CustomResourceDefinition:
         pass
 
     apiextensions = mock.Mock()
     apiextensions.CustomResourceDefinition = CustomResourceDefinition
 
-
     class PodLog:
         pass
 
