@@ -2,8 +2,8 @@ from typing import Dict, Union, List
 from collections.abc import Iterable
 from lightkube import operators
 
-FIELDS_SUPPORT = ('equal', 'not_equal', 'not_in')
-FIELDS_SUPPORT_STR = ', '.join(f'"{fs}"' for fs in FIELDS_SUPPORT)
+FIELDS_SUPPORT = ("equal", "not_equal", "not_in")
+FIELDS_SUPPORT_STR = ", ".join(f'"{fs}"' for fs in FIELDS_SUPPORT)
 
 
 def build_selector(pairs: Union[List, Dict], for_fields=False):
@@ -19,14 +19,20 @@ def build_selector(pairs: Union[List, Dict], for_fields=False):
             v = operators.in_(v)
 
         if not isinstance(v, operators.Operator):
-            raise ValueError(f"selector value '{v}' should be str, None, Iterable or instance of operator")
+            raise ValueError(
+                f"selector value '{v}' should be str, None, Iterable or instance of operator"
+            )
 
         if for_fields and v.op_name not in FIELDS_SUPPORT:
-            raise ValueError(f"parameter 'fields' only support operators {FIELDS_SUPPORT_STR}")
+            raise ValueError(
+                f"parameter 'fields' only support operators {FIELDS_SUPPORT_STR}"
+            )
 
-        if for_fields and v.op_name == 'not_in':    # not_in can be implement using several !=
+        if (
+            for_fields and v.op_name == "not_in"
+        ):  # not_in can be implement using several !=
             for item in v.value:
                 res.append(operators.not_equal(item).encode(k))
         else:
             res.append(v.encode(k))
-    return ','.join(res)
+    return ",".join(res)
