@@ -4,20 +4,22 @@ import typing
 
 
 class PatchType(enum.Enum):
-    JSON = 'application/json-patch+json'
-    MERGE = 'application/merge-patch+json'
-    STRATEGIC = 'application/strategic-merge-patch+json'
-    APPLY = 'application/apply-patch+yaml'
+    JSON = "application/json-patch+json"
+    MERGE = "application/merge-patch+json"
+    STRATEGIC = "application/strategic-merge-patch+json"
+    APPLY = "application/apply-patch+yaml"
+
 
 class CascadeType(enum.Enum):
-    ORPHAN = 'Orphan'
-    BACKGROUND = 'Background'
-    FOREGROUND = 'Foreground'
+    ORPHAN = "Orphan"
+    BACKGROUND = "Background"
+    FOREGROUND = "Foreground"
+
 
 class OnErrorAction(enum.Enum):
-    RETRY = 0       # retry to perform the API call again from the last version
-    STOP = 1        # stop silently the iterator
-    RAISE = 2       # raise the error on the caller scope
+    RETRY = 0  # retry to perform the API call again from the last version
+    STOP = 1  # stop silently the iterator
+    RAISE = 2  # raise the error on the caller scope
 
 
 @dataclass
